<?php
/*
* Plugin Name: Simple Code Minify
* Plugin URI: https://create-accord.com/production/plugins/
* Description: This is a simple plugin that shrinks WordPress as much as possible.
* Version: 1.1.0
* Author: CREATE ACCORD
* Author URI: https://create-accord.com/
* License: GPL2 or later
* License URI: https://www.gnu.org/licenses/gpl-2.0.html
* Text Domain: simple-code-minify
*/

// Security

if (
    !defined('ABSPATH')
) exit;

// Performance

/* ---------------------------------------------
* プラグインをアンインストールしたときの処理
* 有効化したとき、停止時に行う処理はないので省略
* ------------------------------------------- */
// 特に何も増やさないので何もしない。

// plugin start

/* ---------------------------------------------
* load_plugin_textdomain関数で翻訳ファイルをロードする
* ------------------------------------------- */
// 公開しないので翻訳ファイルも存在しないので読み込まない。

/* ---------------------------------------------
* 管理画面にプラグイン設定画面を追加登録する
* ------------------------------------------- */
// 何もしない。

/* ---------------------------------------------
* メインページ：ページ内容の表示・更新処理
* ------------------------------------------- */
// 何もしない。

/* ---------------------------------------------
* サブメニュー「設定」ページ：ページ内容の表示・更新処理
* ------------------------------------------- */
// 何もしない。

/* ---------------------------------------------
* Minify化する
* 
* 元となったプログラムソース先
* PHPでHTML圧縮 - Wordpress対応かも？ - Qiita
* https://qiita.com/nanakochi123456/items/7a3af9b99b68d33a2288
* 投稿者：@nanakochi123456(夜桜 なの)
*
* WordPressですべての処理が終わった後、HTMLが出力される直前に置換処理を実行したかったため、「ob_end_flush();」をどこに置くか調べたときの参考ページ
* WordPressですべての処理が終わった後にコンテンツを置換する方法（アクションフック）
* https://www.wp-benricho.com/wordpress-change-html/
*
* ------------------------------------------- */
add_action('template_redirect', function () {
    if (!is_user_logged_in()) {
        /*
        * 外部CSSファイルを非同期で読み込むようにする
        *
        * 元となったプログラムソース先は失念したため、なし。
        * 結構前にオリジナルテーマを作ったとき、ページ表示速度のできる限りの向上を目指して作成したときに調べて作成したもの。
        *
        */
        add_filter('style_loader_tag', function ($block_css_html, $block_css_handle, $block_css_href, $block_css_media) {
            // ログインしていないときに実行する
            // HTML を変更
            $block_css_html = '<link rel="stylesheet" id="' . $block_css_handle . '-css" ';
            $block_css_html .= 'href="' . $block_css_href . '" media="print" onload="this.media=\'screen\'">' . "\n";
            return $block_css_html;
        }, 10, 4);
        // ログインしていないときに実行する
        // ob_startでMinify化し、出力用バッファを有効にする
        function minify_html_code($code_minify_content)
        {

            $code_minify_search = array(
                '/\s\/\>/s', // XMLの /> を圧縮
                '/\>[^\S ]+/s', // タグの後の空白を削除
                '/[^\S ]+\</s', // タグの前の空白を削除
                '/(\s)+/s', // 連続した空白を削除
                '/(\t)+/s', // 連続したタブを削除
                '/<!--[\s\S]*?-->/s', // コメントを削除
                '/type=\"text\/javascript\"/s' // 今は不要なものを削除
            );
            $code_minify_replace = array(
                '>',
                '>',
                '<',
                '\\1'
            );
            $code_minify_content = preg_replace($code_minify_search, $code_minify_replace, $code_minify_content);
            return $code_minify_content;
        }
        ob_start('minify_html_code');
    }
});
// ob_end_flushでMinify化する出力用バッファを送信してオフにする
add_action('shutdown', function () {
    if (!is_user_logged_in()) {
        // ログインしていないときに実行する
        ob_end_flush();
    }
}, 0);
